@@ -2,15 +2,28 @@
 # -*- coding: utf-8 -*-
 
 import sys
+from datetime import datetime
 from optparse import OptionParser
 from pathlib import Path, PurePath
 from sys import stderr
+from time import sleep as time_sleep
 
 import json5 as json
+import vlc
 
 from exclock import __VERSION__
 from exclock.entities import ClockTimer
-from exclock.util import get_real_json_filename, get_real_sound_filename, is_time_str
+from exclock.util import (
+    convert_specific_time_to_time_delta,
+    get_clock_basenames,
+    get_real_json_filename,
+    get_real_sound_filename,
+    get_specific_time_from_str,
+    get_time_delta_from_str,
+    is_specific_time_str,
+    is_time_delta_str,
+    notify_all,
+)
 
 
 def get_title_from_json_filename(json_filename: str) -> str:
@@ -38,7 +51,7 @@ def check_raw_clock(d) -> None:
         raise ValueError("clock file err: title is not str object.")
 
     for time_s, sound in d["sounds"].items():
-        if not is_time_str(time_s):
+        if not is_time_delta_str(time_s):
             raise ValueError(f"clock file err: {time_s} is not time.")
         if type(sound) != dict:
             raise ValueError(f"clock file err: sound at {time_s} is not dict object.")
@@ -57,15 +70,55 @@ def check_raw_clock(d) -> None:
 
 
 def get_option_parser():
-    usage = "exclock [filename]"
+    usage = "exclock [(filename) | --list]"
     parser = OptionParser(usage=usage, version=__VERSION__)
+    parser.add_option(
+        "-l",
+        "--list",
+        action="store_true",
+        default=False,
+        dest="show_list",
+        help="show clock names in your PC and exit",
+    )
+    parser.add_option("-t", "--time", dest="specified_time", action="store")
 
     return parser
 
 
-def main() -> None:
-    _, args = get_option_parser().parse_args()
+def show_list_main() -> None:
+    for basename in get_clock_basenames():
+        print(basename)
 
+
+def specified_time_main(opt, args) -> None:
+    time_sec = None
+    if is_specific_time_str(opt.specified_time):
+        now_ = datetime.now()
+        time_ = get_specific_time_from_str(opt.specified_time)
+        time_sec = convert_specific_time_to_time_delta(
+            time_, (now_.hour, now_.minute, now_.second))
+    elif is_time_delta_str(opt.specified_time):
+        time_sec = get_time_delta_from_str(opt.specified_time)
+    else:
+        print("time format is illegal.", file=sys.stderr)
+        sys.exit(1)
+
+    try:
+        message = f"Specified time is passed(sec={time_sec})."
+        notify_all(title="Exclock", message=message, spend_time=time_sec)
+
+        warning_sound_filename = get_real_sound_filename("__warning.mp3")
+        p = vlc.MediaPlayer(warning_sound_filename)
+        p.play()
+        while p.get_state() != vlc.State.Ended:
+            time_sleep(0.2)
+    except KeyboardInterrupt:
+        ...
+    finally:
+        print('bye')
+
+
+def play_clock_main(opt, args) -> None:
     if len(args) != 1:
         print("Length of argument should be 1.", file=sys.stderr)
         sys.exit(1)
@@ -99,5 +152,18 @@ def main() -> None:
         print('bye')
 
 
+def main() -> None:
+    opt, args = get_option_parser().parse_args()
+
+    if opt.show_list:
+        show_list_main()
+        sys.exit()
+    if opt.specified_time is not None:
+        specified_time_main(opt, args)
+        sys.exit()
+
+    play_clock_main(opt, args)
+
+
 if __name__ == '__main__':
     main()
